@@ -24,7 +24,7 @@ package com.clustercontrol.collectiverun.bean;
  */
 public class QueueConstant {
     /** 一括制御実行用キュー */
-    public static final String QUEUE_NAME_EXECUTE = "queue/clustercontrol/CollectiveRun/execute";
+    public static final String QUEUE_NAME_EXECUTE = "queue/clustercontrolCollectiveRunExecute";
     /** 一括制御実行結果用キュー */
-    public static final String QUEUE_NAME_STATUS = "queue/clustercontrol/CollectiveRun/status";
+    public static final String QUEUE_NAME_STATUS = "queue/clustercontrolCollectiveRunStatus";
 }
