@@ -89,6 +89,9 @@ public class EJBContoroller {
 	/** ディレクトリ下に作成するファイルの上限 */
 	private final static String MAX_FILE_COUNT = "msg.max.file.count";
 	
+	/** プロパティのキー：キューの名前。 */
+	private final static String QUEUE_NAME = "queue.name";
+	
 	/** コネクション。 */
 	private QueueConnection m_con;
 	
@@ -234,8 +237,14 @@ public class EJBContoroller {
 			m_session = m_con.createQueueSession(false,
 					Session.AUTO_ACKNOWLEDGE);
 			
+			String queueName = QueueConstant.QUEUE_NAME_NOTIFYCONTROL;
+			//キューの名前の取得
+			if (m_props.getProperty(QUEUE_NAME) != null && !m_props.getProperty(QUEUE_NAME).equals("")) {
+				log.info("queue name : " + m_props.getProperty(QUEUE_NAME));
+				queueName = m_props.getProperty(QUEUE_NAME);
+			}
 			//メッセージQueue取得
-			m_queue = (Queue) con.lookup(QueueConstant.QUEUE_NAME_NOTIFYCONTROL);
+			m_queue = (Queue) con.lookup(queueName);
 			
 		} catch (Exception e) {
 			log.error("Init", e);
